﻿using System.Collections.Generic;
using System.Windows.Forms;

namespace WingMan
{
    public static class KeyConversion
    {
        public static readonly Dictionary<MouseButtons, string> MouseButtonsToString =
            new Dictionary<MouseButtons, string>
            {
                {MouseButtons.Left, "Left Mouse Button"},
                {MouseButtons.Middle, "Middle Mouse Button"},
                {MouseButtons.Right, "Right Mouse Button"}
            };

        public static readonly Dictionary<string, MouseButtons> StringToMouseButtons =
            new Dictionary<string, MouseButtons>
            {
                {"Left Mouse Button", MouseButtons.Left},
                {"Middle Mouse Button", MouseButtons.Middle},
                {"Right Mouse Button", MouseButtons.Right}
            };

        public static readonly Dictionary<string, byte> StringToKeys = new Dictionary<string, byte>
        {
            {"None", 0},
            {"LButton", 1},
            {"RButton", 2},
            {"Cancel", 3},
            {"MButton", 4},
            {"XButton1", 5},
            {"XButton2", 6},
            {"Back", 8},
            {"Tab", 9},
            {"LineFeed", 10},
            {"Clear", 12},
            {"Enter", 13},
            {"ShiftKey", 16},
            {"ControlKey", 17},
            {"Menu", 18},
            {"Pause", 19},
            {"CapsLock", 20},
            {"HangulMode", 21},
            {"JunjaMode", 23},
            {"FinalMode", 24},
            {"KanjiMode", 25},
            {"Escape", 27},
            {"IMEConvert", 28},
            {"IMENonconvert", 29},
            {"IMEAccept", 30},
            {"IMEModeChange", 31},
            {"Space", 32},
            {"PageUp", 33},
            {"PageDown", 34},
            {"End", 35},
            {"Home", 36},
            {"Left", 37},
            {"Up", 38},
            {"Right", 39},
            {"Down", 40},
            {"Select", 41},
            {"Print", 42},
            {"Execute", 43},
            {"PrintScreen", 44},
            {"Insert", 45},
            {"Delete", 46},
            {"Help", 47},
            {"D0", 48},
            {"D1", 49},
            {"D2", 50},
            {"D3", 51},
            {"D4", 52},
            {"D5", 53},
            {"D6", 54},
            {"D7", 55},
            {"D8", 56},
            {"D9", 57},
            {"A", 65},
            {"B", 66},
            {"C", 67},
            {"D", 68},
            {"E", 69},
            {"F", 70},
            {"G", 71},
            {"H", 72},
            {"I", 73},
            {"J", 74},
            {"K", 75},
            {"L", 76},
            {"M", 77},
            {"N", 78},
            {"O", 79},
            {"P", 80},
            {"Q", 81},
            {"R", 82},
            {"S", 83},
            {"T", 84},
            {"U", 85},
            {"V", 86},
            {"W", 87},
            {"X", 88},
            {"Y", 89},
            {"Z", 90},
            {"LWin", 91},
            {"RWin", 92},
            {"Apps", 93},
            {"Sleep", 95},
            {"NumPad0", 96},
            {"NumPad1", 97},
            {"NumPad2", 98},
            {"NumPad3", 99},
            {"NumPad4", 100},
            {"NumPad5", 101},
            {"NumPad6", 102},
            {"NumPad7", 103},
            {"NumPad8", 104},
            {"NumPad9", 105},
            {"Multiply", 106},
            {"Add", 107},
            {"Separator", 108},
            {"Subtract", 109},
            {"Decimal", 110},
            {"Divide", 111},
            {"F1", 112},
            {"F2", 113},
            {"F3", 114},
            {"F4", 115},
            {"F5", 116},
            {"F6", 117},
            {"F7", 118},
            {"F8", 119},
            {"F9", 120},
            {"F10", 121},
            {"F11", 122},
            {"F12", 123},
            {"F13", 124},
            {"F14", 125},
            {"F15", 126},
            {"F16", 127},
            {"F17", 128},
            {"F18", 129},
            {"F19", 130},
            {"F20", 131},
            {"F21", 132},
            {"F22", 133},
            {"F23", 134},
            {"F24", 135},
            {"NumLock", 144},
            {"Scroll", 145},
            {"LShiftKey", 160},
            {"RShiftKey", 161},
            {"LControlKey", 162},
            {"RControlKey", 163},
            {"LMenu", 164},
            {"RMenu", 165},
            {"BrowserBack", 166},
            {"BrowserForward", 167},
            {"BrowserRefresh", 168},
            {"BrowserStop", 169},
            {"BrowserSearch", 170},
            {"BrowserFavorites", 171},
            {"BrowserHome", 172},
            {"VolumeMute", 173},
            {"VolumeDown", 174},
            {"VolumeUp", 175},
            {"MediaNextTrack", 176},
            {"MediaPreviousTrack", 177},
            {"MediaStop", 178},
            {"MediaPlayPause", 179},
            {"LaunchMail", 180},
            {"SelectMedia", 181},
            {"LaunchApplication1", 182},
            {"LaunchApplication2", 183},
            {"Oem1", 186},
            {"Oemplus", 187},
            {"Oemcomma", 188},
            {"OemMinus", 189},
            {"OemPeriod", 190},
            {"Oem2", 191},
            {"Oem3", 192},
            {"Oem4", 219},
            {"Oem5", 220},
            {"Oem6", 221},
            {"Oem7", 222},
            {"Oem8", 223},
            {"Oem102", 226},
            {"ProcessKey", 229},
            {"Packet", 231},
            {"Attn", 246},
            {"Crsel", 247},
            {"Exsel", 248},
            {"EraseEof", 249},
            {"Play", 250},
            {"Zoom", 251},
            {"NoName", 252},
            {"Pa1", 253},
            {"OemClear", 254}
        };

        public static readonly Dictionary<byte, string> KeysToString = new Dictionary<byte, string>
        {
            {0, "None"},
            {1, "LButton"},
            {2, "RButton"},
            {3, "Cancel"},
            {4, "MButton"},
            {5, "XButton1"},
            {6, "XButton2"},
            {8, "Back"},
            {9, "Tab"},
            {10, "LineFeed"},
            {12, "Clear"},
            {13, "Enter"},
            {16, "ShiftKey"},
            {17, "ControlKey"},
            {18, "Menu"},
            {19, "Pause"},
            {20, "CapsLock"},
            {21, "HanguelMode"},
            {23, "JunjaMode"},
            {24, "FinalMode"},
            {25, "KanjiMode"},
            {27, "Escape"},
            {28, "IMEConvert"},
            {29, "IMENonconvert"},
            {30, "IMEAccept"},
            {31, "IMEModeChange"},
            {32, "Space"},
            {33, "PageUp"},
            {34, "PageDown"},
            {35, "End"},
            {36, "Home"},
            {37, "Left"},
            {38, "Up"},
            {39, "Right"},
            {40, "Down"},
            {41, "Select"},
            {42, "Print"},
            {43, "Execute"},
            {44, "PrintScreen"},
            {45, "Insert"},
            {46, "Delete"},
            {47, "Help"},
            {48, "D0"},
            {49, "D1"},
            {50, "D2"},
            {51, "D3"},
            {52, "D4"},
            {53, "D5"},
            {54, "D6"},
            {55, "D7"},
            {56, "D8"},
            {57, "D9"},
            {65, "A"},
            {66, "B"},
            {67, "C"},
            {68, "D"},
            {69, "E"},
            {70, "F"},
            {71, "G"},
            {72, "H"},
            {73, "I"},
            {74, "J"},
            {75, "K"},
            {76, "L"},
            {77, "M"},
            {78, "N"},
            {79, "O"},
            {80, "P"},
            {81, "Q"},
            {82, "R"},
            {83, "S"},
            {84, "T"},
            {85, "U"},
            {86, "V"},
            {87, "W"},
            {88, "X"},
            {89, "Y"},
            {90, "Z"},
            {91, "LWin"},
            {92, "RWin"},
            {93, "Apps"},
            {95, "Sleep"},
            {96, "NumPad0"},
            {97, "NumPad1"},
            {98, "NumPad2"},
            {99, "NumPad3"},
            {100, "NumPad4"},
            {101, "NumPad5"},
            {102, "NumPad6"},
            {103, "NumPad7"},
            {104, "NumPad8"},
            {105, "NumPad9"},
            {106, "Multiply"},
            {107, "Add"},
            {108, "Separator"},
            {109, "Subtract"},
            {110, "Decimal"},
            {111, "Divide"},
            {112, "F1"},
            {113, "F2"},
            {114, "F3"},
            {115, "F4"},
            {116, "F5"},
            {117, "F6"},
            {118, "F7"},
            {119, "F8"},
            {120, "F9"},
            {121, "F10"},
            {122, "F11"},
            {123, "F12"},
            {124, "F13"},
            {125, "F14"},
            {126, "F15"},
            {127, "F16"},
            {128, "F17"},
            {129, "F18"},
            {130, "F19"},
            {131, "F20"},
            {132, "F21"},
            {133, "F22"},
            {134, "F23"},
            {135, "F24"},
            {144, "NumLock"},
            {145, "Scroll"},
            {160, "LShiftKey"},
            {161, "RShiftKey"},
            {162, "LControlKey"},
            {163, "RControlKey"},
            {164, "LMenu"},
            {165, "RMenu"},
            {166, "BrowserBack"},
            {167, "BrowserForward"},
            {168, "BrowserRefresh"},
            {169, "BrowserStop"},
            {170, "BrowserSearch"},
            {171, "BrowserFavorites"},
            {172, "BrowserHome"},
            {173, "VolumeMute"},
            {174, "VolumeDown"},
            {175, "VolumeUp"},
            {176, "MediaNextTrack"},
            {177, "MediaPreviousTrack"},
            {178, "MediaStop"},
            {179, "MediaPlayPause"},
            {180, "LaunchMail"},
            {181, "SelectMedia"},
            {182, "LaunchApplication1"},
            {183, "LaunchApplication2"},
            {186, "Oem1"},
            {187, "Oemplus"},
            {188, "Oemcomma"},
            {189, "OemMinus"},
            {190, "OemPeriod"},
            {191, "Oem2"},
            {192, "Oem3"},
            {219, "Oem4"},
            {220, "Oem5"},
            {221, "Oem6"},
            {222, "Oem7"},
            {223, "Oem8"},
            {226, "Oem102"},
            {229, "ProcessKey"},
            {231, "Packet"},
            {246, "Attn"},
            {247, "Crsel"},
            {248, "Exsel"},
            {249, "EraseEof"},
            {250, "Play"},
            {251, "Zoom"},
            {252, "NoName"},
            {253, "Pa1"},
            {254, "OemClear"}
        };
    }
}
